"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Data_1 = require("./Data");
const utils_1 = require("../utils");
const symbols_1 = require("../symbols");
const libs_1 = require("../libs");
class Validation extends Data_1.Data {
    /**
     * Runs before any validations are run
     */
    preValidate() {
        return;
    }
    /**
     * Runs after successful validation ran
     */
    postValidate() {
        return;
    }
    /**
     * Runs the validation of each data class attributes and
     * throw an exception if one of the attribute is not valid.
     */
    validate() {
        const callPreValidate = () => {
            this.debug('::preValidate', 'airboat:validation');
            return this.preValidate();
        };
        const callPostValidate = () => {
            this.debug('::postValidate', 'airboat:validation');
            return this.postValidate();
        };
        const callValidate = () => {
            this.debug('::validate', 'airboat:validation');
            const validationErrors = [];
            const newValues = {};
            Object.keys(this[symbols_1.CLASS_DATA_ATTRIBUTES]).forEach((attrKey) => {
                const attrDef = this[symbols_1.CLASS_DATA_ATTRIBUTES][attrKey];
                if (attrDef.validation) {
                    const results = libs_1.Joi.validate(this[attrKey], attrDef.validation);
                    if (results.error) {
                        validationErrors.push(results.error.message.replace('"value"', `${this.getClassNameForErrorMessage()}.${attrKey}`));
                    }
                    else {
                        newValues[attrKey] = results.value;
                    }
                }
                else {
                    newValues[attrKey] = this[attrKey];
                }
            });
            if (validationErrors.length >= 1) {
                throw utils_1.Exception.badRequest(validationErrors.join('; '));
            }
            Object.assign(this, newValues);
        };
        callPreValidate();
        callValidate();
        callPostValidate();
        return this;
    }
    getClassNameForErrorMessage() {
        return this.constructor.name;
    }
}
exports.Validation = Validation;
//# sourceMappingURL=Validation.js.map