"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const symbols_1 = require("./symbols");
const uuid_1 = require("uuid");
const libs_1 = require("./libs");
const services_1 = require("./services");
const DEBUG_KEY = 'airboat:common:decorators';
/**
 * @Attribute({ validation: Joi.string().required()})
 * @Attribute(Joi.string().required())
 */
// tslint:disable-next-line: function-name
function Attribute(attribute = {}) {
    return (target, attributeKey) => {
        services_1.Logger.debug(JSON.stringify(target.constructor.name), DEBUG_KEY);
        const attributeProps = libs_1._.has(attribute, 'isJoi')
            ? { validation: attribute }
            : attribute;
        symbols_1.initClassDataSymbols(target);
        attributeProps.name = attributeProps.name || attributeKey;
        target[symbols_1.CLASS_DATA_ATTRIBUTES][attributeKey] = attributeProps;
    };
}
exports.Attribute = Attribute;
/**
 * @Attribute.model(MyModel, { optional: false })
 */
Attribute.model = (modelClass, options = { optional: false }, attribute = {}) => {
    const validation = options.optional
        ? libs_1.Joi.object().model().optional()
        : libs_1.Joi.object().model().required();
    return Attribute(libs_1._.defaults(attribute, {
        validation,
        deserialize: (o = {}) => new modelClass(o),
        serialize: (o) => o.serialize(),
    }));
};
/**
 * @Attribute.modelList(MyModel)
 */
Attribute.modelList = (model, options = {}, attribute = {}) => {
    return Attribute(libs_1._.defaults(attribute, {
        validation: libs_1.Joi.array().items(libs_1.Joi.object().model()).required(),
        deserialize: (list = []) => list.map((a) => new model(a)),
        serialize: (list) => list.map((a) => a.serialize()),
    }));
};
/**
 * @Attribute.dateTime()
 */
Attribute.dateTime = (options = {}, attribute = {}) => {
    return Attribute(libs_1._.defaults(attribute, {
        validation: libs_1.Joi.date().default(() => new Date(), 'now').optional(),
        deserialize: (o) => o ? new Date(o) : undefined,
        serialize: (o) => o.toISOString(),
    }));
};
/**
 * @Attribute.uuid({ required: false })
 */
Attribute.uuid = (options = { required: false }, attribute = {}) => {
    const validation = options.required
        ? libs_1.Joi.string().guid().required()
        : libs_1.Joi.string().guid().default(uuid_1.v4, 'new uuid').optional();
    return Attribute(libs_1._.defaults(attribute, { validation }));
};
/**
 * @Attribute.workspaceId()
 */
Attribute.workspaceId = (options = {}, attribute = {}) => {
    return Attribute(libs_1._.defaults(attribute, {
        validation: libs_1.Joi.string().guid().required(),
    }));
};
/**
 * @Attribute.key()
 */
Attribute.key = (options = {}, attribute = {}) => {
    return Attribute(libs_1._.defaults(attribute, {
        validation: libs_1.Joi.string().lowercase().trim().min(10).max(255).required(),
    }));
};
//# sourceMappingURL=decorators.js.map