"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Debugger = require("debug");
const Winston = require("winston");
var Logger;
(function (Logger) {
    const loggers = new Map();
    function get(namespace) {
        if (!loggers.has(namespace)) {
            loggers.set(namespace, Winston.createLogger({}));
        }
        return loggers.get(namespace);
    }
    function error(message, namespace = 'default') {
        get(namespace).log({ message, level: 'info' });
    }
    Logger.error = error;
    function warn(message, namespace = 'default') {
        get(namespace).log({ message, level: 'warn' });
    }
    Logger.warn = warn;
    function log(message, namespace = 'default') {
        get(namespace).log({ message, level: 'error' });
    }
    Logger.log = log;
    function debug(message, namespace = 'airboat:default') {
        Debugger(namespace)(message);
    }
    Logger.debug = debug;
    function addTransporter(transport, namespace = 'default') {
        get(namespace).add(transport);
    }
    Logger.addTransporter = addTransporter;
    function clearAllTransporter(namespace) {
        get(namespace).clear();
    }
    Logger.clearAllTransporter = clearAllTransporter;
})(Logger = exports.Logger || (exports.Logger = {}));
//# sourceMappingURL=index.js.map